@@ -1,3 +1,5 @@
+from enum import Enum
+
 from pydantic import BaseModel
 
 AdvisoryRecord = tuple[
@@ -13,9 +15,23 @@ AdvisoryRecord = tuple[
     str | None,  # cwe_ids
     str | None,  # cve_finding
     int,  # auto_approve
+    str | None,  # fixed_versions
 ]
 
 
+class UpgradeType(str, Enum):
+    UNKNOWN = "unknown"
+    MAJOR = "major"
+    MINOR = "minor"
+    PATCH = "patch"
+
+
+class AdvisoryFixMetadata(BaseModel):
+    closest_fix_version: str | None
+    upgrade_type: UpgradeType
+    breaking_change: bool
+
+
 class Advisory(BaseModel):
     id: str
     vulnerable_version: str
@@ -23,6 +39,8 @@ class Advisory(BaseModel):
     package_manager: str
     cpes: list[str]
     severity_level: str = "Low"
+    fixed_versions: list[str] | None = None
+    fix_metadata: AdvisoryFixMetadata | None = None
     details: str | None = None
     epss: float = 0.0
     percentile: float = 0.0
@@ -31,3 +49,4 @@ class Advisory(BaseModel):
     cwe_ids: list[str] | None = None
     cve_finding: str | None = None
     auto_approve: bool = False
+    upstream_package: str | None = None
